@@ -3,6 +3,7 @@ package segments
 import (
 	"fmt"
 	"sort"
+	"strconv"
 	"strings"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
@@ -190,13 +191,40 @@ func (pt *Path) setStyle() {
 	case FolderType:
 		pt.Path = pt.getFolderPath()
 	case Powerlevel:
-		maxWidth := int(pt.props.GetFloat64(MaxWidth, 0))
+		maxWidth := pt.getMaxWidth()
 		pt.Path = pt.getUniqueLettersPath(maxWidth)
 	default:
 		pt.Path = fmt.Sprintf("Path style: %s is not available", style)
 	}
 }
 
+func (pt *Path) getMaxWidth() int {
+	width := pt.props.GetString(MaxWidth, "")
+	if len(width) == 0 {
+		return 0
+	}
+
+	tmpl := &template.Text{
+		Template: width,
+		Context:  pt,
+		Env:      pt.env,
+	}
+
+	text, err := tmpl.Render()
+	if err != nil {
+		pt.env.Error(err)
+		return 0
+	}
+
+	value, err := strconv.Atoi(text)
+	if err != nil {
+		pt.env.Error(err)
+		return 0
+	}
+
+	return value
+}
+
 func (pt *Path) getFolderSeparator() string {
 	separatorTemplate := pt.props.GetString(FolderSeparatorTemplate, "")
 	if len(separatorTemplate) == 0 {
