@@ -60,6 +60,7 @@ module.exports = {
         "segments/bazel",
         "segments/brewfather",
         "segments/buf",
+        "segments/bun",
         "segments/carbonintensity",
         "segments/cds",
         "segments/cf",
@@ -103,6 +104,7 @@ module.exports = {
         "segments/perl",
         "segments/php",
         "segments/plastic",
+        "segments/pnpm",
         "segments/project",
         "segments/pulumi",
         "segments/python",
